@@ -28,6 +28,7 @@ from __future__ import absolute_import, division, print_function
 
 import warnings
 from functools import wraps
+
 import idutils
 
 from .utils import normalize_author_name_with_comma, validate
@@ -107,7 +108,7 @@ class LiteratureBuilder(object):
     def _append_to(self, field, element):
         """Append the ``element`` to the ``field`` of the record.
 
-        This method is smart: it does nothing if ``field`` is empty and
+        This method is smart: it does nothing if ``element`` is empty and
         creates ``field`` if it does not exit yet.
 
         :param field: the name of the field of the record to append to
@@ -118,6 +119,20 @@ class LiteratureBuilder(object):
             self.record.setdefault(field, [])
             self.record.get(field).append(element)
 
+    def _prepend_to(self, field, element):
+        """Prepend the ``element`` to the ``field`` of the record.
+
+        This method is smart: it does nothing if ``element`` is empty and
+        creates ``field`` if it does not exit yet.
+
+        :param field: the name of the field of the record to prepend to
+        :type field: string
+        :param element: the element to prepend
+        """
+        if element not in EMPTIES:
+            self.record.setdefault(field, [])
+            self.record.get(field).insert(0, element)
+
     def __str__(self):
         """Print the current record."""
         return str(self.record)
@@ -170,7 +185,7 @@ class LiteratureBuilder(object):
         self.set_citeable(True)
 
     @filter_empty_parameters
-    def add_doi(self, doi, source=None):
+    def add_doi(self, doi, source=None, material=None):
         """Add doi.
 
         :param doi: doi for the current document.
@@ -178,12 +193,21 @@ class LiteratureBuilder(object):
 
         :param source: source for the doi.
         :type source: string
+
+        :param material: material for the doi.
+        :type material: string
         """
-        if idutils.normalize_doi(doi):
-            self._append_to('dois', {
-                'value': doi,
-                'source': self._get_source(source),
-            })
+        if not idutils.normalize_doi(doi):
+            return
+
+        dois = {
+            'value': doi,
+            'source': self._get_source(source)
+        }
+        if material is not None:
+            dois['material'] = material
+
+        self._append_to('dois', dois)
 
     @filter_empty_parameters
     def add_author(self, author):
@@ -341,6 +365,8 @@ class LiteratureBuilder(object):
         journal_title=None,
         journal_volume=None,
         pubinfo_freetext=None,
+        material=None,
+        parent_record=None,
     ):
         """Add publication info.
 
@@ -374,14 +400,22 @@ class LiteratureBuilder(object):
         :param pubinfo_freetext: Unstructured text describing the publication
         information.
         :type pubinfo_freetext: string
+
+        :param material: material of the article
+        :type material: string
+
+        :param parent_record: reference for the parent record
+        :type parent_record: string
         """
         publication_item = {}
         for key in ('cnum', 'artid', 'page_end', 'page_start',
                     'journal_issue', 'journal_title',
-                    'journal_volume', 'year', 'pubinfo_freetext'):
+                    'journal_volume', 'year', 'pubinfo_freetext', 'material'):
             if locals()[key] is not None:
                 publication_item[key] = locals()[key]
-
+        if parent_record is not None:
+            parent_item = {'$ref': parent_record}
+            publication_item['parent_record'] = parent_item
         if page_start and page_end:
             try:
                 self.add_number_of_pages(
@@ -631,8 +665,6 @@ class LiteratureBuilder(object):
             warnings.warn("Use 'datetime', not 'date'", DeprecationWarning)
             datetime = date
 
-        self.record.setdefault('acquisition_source', {})
-
         acquisition_source = {}
 
         acquisition_source['submission_number'] = str(submission_number)
@@ -641,7 +673,7 @@ class LiteratureBuilder(object):
             if locals()[key] is not None:
                 acquisition_source[key] = locals()[key]
 
-        self.record['acquisition_source'] = acquisition_source
+        self._prepend_to('acquisition_sources', acquisition_source)
 
     @filter_empty_parameters
     def add_document_type(self, document_type):
